==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/General/listenbrainz/translations/listenbrainz_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>ListenBrainzFactory</name>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="30"/>
        <source>ListenBrainz Plugin</source>
        <translation>ListenBrainz Plugin</translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="50"/>
        <source>About ListenBrainz Plugin</source>
        <translation>Tietoja: ListenBrainz Plugin</translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="51"/>
        <source>Qmmp ListenBrainz Plugin</source>
        <translation>Qmmp ListenBrainz Plugin</translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="52"/>
        <source>This plugin submits listen history to ListenBrainz server</source>
        <translation>Tämä laajennus lähettää kuunteluhistorian ListenBrainz-palvelimelle</translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Kirjoittanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ListenBrainz Plugin Settings</source>
        <translation>Asetukset ListenBrainz Plugin</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>ListenBrainz user token:</source>
        <translation>Käyttäjän tunnus ListenBrainz:</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.6.tar.bz2: qmmp-2.2.6/src/plugins/General/listenbrainz/translations/listenbrainz_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>ListenBrainzFactory</name>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="30"/>
        <source>ListenBrainz Plugin</source>
        <translation>ListenBrainz Plugin</translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="50"/>
        <source>About ListenBrainz Plugin</source>
        <translation>Tietoja: ListenBrainz Plugin</translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="51"/>
        <source>Qmmp ListenBrainz Plugin</source>
        <translation>Qmmp ListenBrainz Plugin</translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="52"/>
        <source>This plugin submits listen history to ListenBrainz server</source>
        <translation>Tämä laajennus lähettää kuunteluhistorian ListenBrainz-palvelimelle</translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Kirjoittanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>ListenBrainzSettingsDialog</name>
    <message>
        <location filename="../listenbrainzsettingsdialog.ui" line="14"/>
        <source>ListenBrainz Plugin Settings</source>
        <translation>Asetukset ListenBrainz Plugin</translation>
    </message>
    <message>
        <location filename="../listenbrainzsettingsdialog.ui" line="29"/>
        <source>ListenBrainz user token:</source>
        <translation>Käyttäjän tunnus ListenBrainz:</translation>
    </message>
</context>
</TS>
